pub enum CryptoSystemResponseOp {
Show 35 variants
InvalidId,
Release,
Kind {
value: CryptoKind,
},
CachedDh {
result: ApiResultWithString<SharedSecret>,
},
ComputeDh {
result: ApiResultWithString<SharedSecret>,
},
GenerateSharedSecret {
result: ApiResultWithString<SharedSecret>,
},
RandomBytes {
value: Vec<u8>,
},
SharedSecretLength {
value: u32,
},
NonceLength {
value: u32,
},
HashDigestLength {
value: u32,
},
PublicKeyLength {
value: u32,
},
SecretKeyLength {
value: u32,
},
SignatureLength {
value: u32,
},
DefaultSaltLength {
value: u32,
},
AeadOverhead {
value: u32,
},
CheckSharedSecret {
result: ApiResult<()>,
},
CheckNonce {
result: ApiResult<()>,
},
CheckHashDigest {
result: ApiResult<()>,
},
CheckPublicKey {
result: ApiResult<()>,
},
CheckSecretKey {
result: ApiResult<()>,
},
CheckSignature {
result: ApiResult<()>,
},
HashPassword {
result: ApiResult<String>,
},
VerifyPassword {
result: ApiResult<bool>,
},
DeriveSharedSecret {
result: ApiResultWithString<SharedSecret>,
},
RandomNonce {
value: Nonce,
},
RandomSharedSecret {
value: SharedSecret,
},
GenerateKeyPair {
value: KeyPair,
},
GenerateHash {
value: HashDigest,
},
ValidateKeyPair {
result: ApiResult<bool>,
},
ValidateHash {
result: ApiResult<bool>,
},
Sign {
result: ApiResultWithString<Signature>,
},
Verify {
result: ApiResult<bool>,
},
DecryptAead {
result: ApiResultWithVecU8,
},
EncryptAead {
result: ApiResultWithVecU8,
},
CryptNoAuth {
result: ApiResultWithVecU8,
},
}Variants
InvalidId
Release
Kind
Fields

value: CryptoKindCachedDh
Fields

result: ApiResultWithString<SharedSecret>ComputeDh
Fields

result: ApiResultWithString<SharedSecret>RandomBytes
NonceLength
HashDigestLength
PublicKeyLength
SecretKeyLength
SignatureLength
DefaultSaltLength
AeadOverhead
CheckNonce
CheckHashDigest
CheckPublicKey
CheckSecretKey
CheckSignature
HashPassword
VerifyPassword
RandomNonce
GenerateKeyPair
GenerateHash
Fields

value: HashDigestValidateKeyPair
ValidateHash
Sign
Fields

result: ApiResultWithString<Signature>Verify
DecryptAead
Fields

result: ApiResultWithVecU8EncryptAead
Fields

result: ApiResultWithVecU8CryptNoAuth
Fields

result: ApiResultWithVecU8Trait Implementations
Sourceimpl Clone for CryptoSystemResponseOp
impl Clone for CryptoSystemResponseOp
Sourcefn clone(&self) -> CryptoSystemResponseOp
fn clone(&self) -> CryptoSystemResponseOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CryptoSystemResponseOp
impl Debug for CryptoSystemResponseOp
Sourceimpl<'de> Deserialize<'de> for CryptoSystemResponseOp
impl<'de> Deserialize<'de> for CryptoSystemResponseOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CryptoSystemResponseOp
impl JsonSchema for CryptoSystemResponseOp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for CryptoSystemResponseOp
impl RefUnwindSafe for CryptoSystemResponseOp
impl Send for CryptoSystemResponseOp
impl Sync for CryptoSystemResponseOp
impl Unpin for CryptoSystemResponseOp
impl UnsafeUnpin for CryptoSystemResponseOp
impl UnwindSafe for CryptoSystemResponseOp