pub enum ResponseOp {
Show 33 variants
Control {
result: ApiResult<String>,
},
GetState {
result: ApiResult<Box<VeilidState>>,
},
IsShutdown {
value: bool,
},
Attach {
result: ApiResult<()>,
},
Detach {
result: ApiResult<()>,
},
GenerateMemberId {
result: ApiResultWithString<MemberId>,
},
GetDhtRecordKey {
result: ApiResultWithString<RecordKey>,
},
NewPrivateRoute {
result: ApiResult<RouteBlob>,
},
NewCustomPrivateRoute {
result: ApiResult<RouteBlob>,
},
ImportRemotePrivateRoute {
result: ApiResultWithString<RouteId>,
},
ReleasePrivateRoute {
result: ApiResult<()>,
},
AppCallReply {
result: ApiResult<()>,
},
NewRoutingContext {
result: ApiResult<u32>,
},
RoutingContext(Box<RoutingContextResponse>),
TransactDhtRecords {
result: ApiResult<u32>,
},
DhtTransaction(Box<DhtTransactionResponse>),
OpenTableDb {
result: ApiResult<u32>,
},
DeleteTableDb {
result: ApiResult<bool>,
},
TableDb(TableDbResponse),
TableDbTransaction(TableDbTransactionResponse),
GetCryptoSystem {
result: ApiResult<u32>,
},
BestCryptoSystem {
result: ApiResult<u32>,
},
CryptoSystem(CryptoSystemResponse),
VerifySignatures {
result: ApiResultWithOptVecString<Option<PublicKeyGroup>>,
},
GenerateSignatures {
result: ApiResultWithVecString<Vec<Signature>>,
},
GenerateKeyPair {
result: ApiResultWithString<KeyPair>,
},
Now {
value: Timestamp,
},
Debug {
result: ApiResult<String>,
},
VeilidVersionString {
value: String,
},
VeilidVersion {
major: u32,
minor: u32,
patch: u32,
},
DefaultVeilidConfig {
value: String,
},
VeilidFeatures {
value: Vec<String>,
},
ValidCryptoKinds {
value: Vec<CryptoKind>,
},
}Variants
Control
GetState
Fields

result: ApiResult<Box<VeilidState>>IsShutdown
Attach
Detach
GenerateMemberId
Fields

result: ApiResultWithString<MemberId>GetDhtRecordKey
Fields

result: ApiResultWithString<RecordKey>NewPrivateRoute
NewCustomPrivateRoute
ImportRemotePrivateRoute
Fields

result: ApiResultWithString<RouteId>ReleasePrivateRoute
AppCallReply
NewRoutingContext
RoutingContext(Box<RoutingContextResponse>)
TransactDhtRecords
DhtTransaction(Box<DhtTransactionResponse>)
OpenTableDb
DeleteTableDb
TableDb(TableDbResponse)
TableDbTransaction(TableDbTransactionResponse)
GetCryptoSystem
BestCryptoSystem
CryptoSystem(CryptoSystemResponse)
VerifySignatures
Fields

result: ApiResultWithOptVecString<Option<PublicKeyGroup>>GenerateSignatures
Fields

result: ApiResultWithVecString<Vec<Signature>>GenerateKeyPair
Fields

result: ApiResultWithString<KeyPair>Now
Debug
VeilidVersionString
VeilidVersion
DefaultVeilidConfig
VeilidFeatures
ValidCryptoKinds
Fields

value: Vec<CryptoKind>Trait Implementations
Sourceimpl Clone for ResponseOp
impl Clone for ResponseOp
Sourcefn clone(&self) -> ResponseOp
fn clone(&self) -> ResponseOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseOp
impl Debug for ResponseOp
Sourceimpl<'de> Deserialize<'de> for ResponseOp
impl<'de> Deserialize<'de> for ResponseOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResponseOp
impl JsonSchema for ResponseOp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for ResponseOp
impl RefUnwindSafe for ResponseOp
impl Send for ResponseOp
impl Sync for ResponseOp
impl Unpin for ResponseOp
impl UnwindSafe for ResponseOp