pub enum RoutingContextResponseOp {
Show 17 variants
InvalidId,
Release,
WithDefaultSafety {
result: ApiResult<u32>,
},
WithSafety {
result: ApiResult<u32>,
},
WithSequencing {
value: u32,
},
Safety {
value: SafetySelection,
},
AppCall {
result: ApiResultWithVecU8,
},
AppMessage {
result: ApiResult<()>,
},
CreateDhtRecord {
result: ApiResult<Box<DHTRecordDescriptor>>,
},
OpenDhtRecord {
result: ApiResult<Box<DHTRecordDescriptor>>,
},
CloseDhtRecord {
result: ApiResult<()>,
},
DeleteDhtRecord {
result: ApiResult<()>,
},
GetDhtValue {
result: ApiResult<Option<ValueData>>,
},
SetDhtValue {
result: ApiResult<Option<ValueData>>,
},
WatchDhtValues {
result: ApiResult<bool>,
},
CancelDhtWatch {
result: ApiResult<bool>,
},
InspectDhtRecord {
result: ApiResult<Box<DHTRecordReport>>,
},
}Variants
InvalidId
Release
WithDefaultSafety
WithSafety
WithSequencing
Safety
Fields

value: SafetySelectionAppCall
Fields

result: ApiResultWithVecU8AppMessage
CreateDhtRecord
Fields

result: ApiResult<Box<DHTRecordDescriptor>>OpenDhtRecord
Fields

result: ApiResult<Box<DHTRecordDescriptor>>CloseDhtRecord
DeleteDhtRecord
GetDhtValue
SetDhtValue
WatchDhtValues
CancelDhtWatch
InspectDhtRecord
Fields

result: ApiResult<Box<DHTRecordReport>>Trait Implementations
Sourceimpl Clone for RoutingContextResponseOp
impl Clone for RoutingContextResponseOp
Sourcefn clone(&self) -> RoutingContextResponseOp
fn clone(&self) -> RoutingContextResponseOp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoutingContextResponseOp
impl Debug for RoutingContextResponseOp
Sourceimpl<'de> Deserialize<'de> for RoutingContextResponseOp
impl<'de> Deserialize<'de> for RoutingContextResponseOp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoutingContextResponseOp
impl JsonSchema for RoutingContextResponseOp
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for RoutingContextResponseOp
impl RefUnwindSafe for RoutingContextResponseOp
impl Send for RoutingContextResponseOp
impl Sync for RoutingContextResponseOp
impl Unpin for RoutingContextResponseOp
impl UnwindSafe for RoutingContextResponseOp