pub struct CryptoSystemResponse {
pub cs_id: u32,
pub cs_op: CryptoSystemResponseOp,
}Fields
cs_id: u32cs_op: CryptoSystemResponseOpTrait Implementations
Sourceimpl Clone for CryptoSystemResponse
impl Clone for CryptoSystemResponse
Sourcefn clone(&self) -> CryptoSystemResponse
fn clone(&self) -> CryptoSystemResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CryptoSystemResponse
impl Debug for CryptoSystemResponse
Sourceimpl<'de> Deserialize<'de> for CryptoSystemResponse
impl<'de> Deserialize<'de> for CryptoSystemResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CryptoSystemResponse
impl JsonSchema for CryptoSystemResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for CryptoSystemResponse
impl RefUnwindSafe for CryptoSystemResponse
impl Send for CryptoSystemResponse
impl Sync for CryptoSystemResponse
impl Unpin for CryptoSystemResponse
impl UnsafeUnpin for CryptoSystemResponse
impl UnwindSafe for CryptoSystemResponse