pub struct DhtTransactionRequest {
pub dhttx_id: u32,
pub dhttx_op: DhtTransactionRequestOp,
}Fields
dhttx_id: u32dhttx_op: DhtTransactionRequestOpTrait Implementations
Sourceimpl Clone for DhtTransactionRequest
impl Clone for DhtTransactionRequest
Sourcefn clone(&self) -> DhtTransactionRequest
fn clone(&self) -> DhtTransactionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DhtTransactionRequest
impl Debug for DhtTransactionRequest
Sourceimpl<'de> Deserialize<'de> for DhtTransactionRequest
impl<'de> Deserialize<'de> for DhtTransactionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DhtTransactionRequest
impl JsonSchema for DhtTransactionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for DhtTransactionRequest
impl RefUnwindSafe for DhtTransactionRequest
impl Send for DhtTransactionRequest
impl Sync for DhtTransactionRequest
impl Unpin for DhtTransactionRequest
impl UnsafeUnpin for DhtTransactionRequest
impl UnwindSafe for DhtTransactionRequest