pub struct DhtTransactionResponse {
pub dhttx_id: u32,
pub dhttx_op: DhtTransactionResponseOp,
}Fields
dhttx_id: u32dhttx_op: DhtTransactionResponseOpTrait Implementations
Sourceimpl Clone for DhtTransactionResponse
impl Clone for DhtTransactionResponse
Sourcefn clone(&self) -> DhtTransactionResponse
fn clone(&self) -> DhtTransactionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DhtTransactionResponse
impl Debug for DhtTransactionResponse
Sourceimpl<'de> Deserialize<'de> for DhtTransactionResponse
impl<'de> Deserialize<'de> for DhtTransactionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DhtTransactionResponse
impl JsonSchema for DhtTransactionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for DhtTransactionResponse
impl RefUnwindSafe for DhtTransactionResponse
impl Send for DhtTransactionResponse
impl Sync for DhtTransactionResponse
impl Unpin for DhtTransactionResponse
impl UnsafeUnpin for DhtTransactionResponse
impl UnwindSafe for DhtTransactionResponse