pub struct RoutingContextRequest {
pub rc_id: u32,
pub rc_op: RoutingContextRequestOp,
}Fields
rc_id: u32rc_op: RoutingContextRequestOpTrait Implementations
Sourceimpl Clone for RoutingContextRequest
impl Clone for RoutingContextRequest
Sourcefn clone(&self) -> RoutingContextRequest
fn clone(&self) -> RoutingContextRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoutingContextRequest
impl Debug for RoutingContextRequest
Sourceimpl<'de> Deserialize<'de> for RoutingContextRequest
impl<'de> Deserialize<'de> for RoutingContextRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoutingContextRequest
impl JsonSchema for RoutingContextRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for RoutingContextRequest
impl RefUnwindSafe for RoutingContextRequest
impl Send for RoutingContextRequest
impl Sync for RoutingContextRequest
impl Unpin for RoutingContextRequest
impl UnsafeUnpin for RoutingContextRequest
impl UnwindSafe for RoutingContextRequest