pub struct RoutingContextResponse {
pub rc_id: u32,
pub rc_op: RoutingContextResponseOp,
}Fields
rc_id: u32rc_op: RoutingContextResponseOpTrait Implementations
Sourceimpl Clone for RoutingContextResponse
impl Clone for RoutingContextResponse
Sourcefn clone(&self) -> RoutingContextResponse
fn clone(&self) -> RoutingContextResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RoutingContextResponse
impl Debug for RoutingContextResponse
Sourceimpl<'de> Deserialize<'de> for RoutingContextResponse
impl<'de> Deserialize<'de> for RoutingContextResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RoutingContextResponse
impl JsonSchema for RoutingContextResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for RoutingContextResponse
impl RefUnwindSafe for RoutingContextResponse
impl Send for RoutingContextResponse
impl Sync for RoutingContextResponse
impl Unpin for RoutingContextResponse
impl UnsafeUnpin for RoutingContextResponse
impl UnwindSafe for RoutingContextResponse