pub struct TableDbRequest {
pub db_id: u32,
pub db_op: TableDbRequestOp,
}Fields
db_id: u32db_op: TableDbRequestOpTrait Implementations
Sourceimpl Clone for TableDbRequest
impl Clone for TableDbRequest
Sourcefn clone(&self) -> TableDbRequest
fn clone(&self) -> TableDbRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableDbRequest
impl Debug for TableDbRequest
Sourceimpl<'de> Deserialize<'de> for TableDbRequest
impl<'de> Deserialize<'de> for TableDbRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TableDbRequest
impl JsonSchema for TableDbRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TableDbRequest
impl RefUnwindSafe for TableDbRequest
impl Send for TableDbRequest
impl Sync for TableDbRequest
impl Unpin for TableDbRequest
impl UnwindSafe for TableDbRequest