pub struct TableDbTransactionRequest {
pub tx_id: u32,
pub tx_op: TableDbTransactionRequestOp,
}Fields
tx_id: u32tx_op: TableDbTransactionRequestOpTrait Implementations
Sourceimpl Clone for TableDbTransactionRequest
impl Clone for TableDbTransactionRequest
Sourcefn clone(&self) -> TableDbTransactionRequest
fn clone(&self) -> TableDbTransactionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableDbTransactionRequest
impl Debug for TableDbTransactionRequest
Sourceimpl<'de> Deserialize<'de> for TableDbTransactionRequest
impl<'de> Deserialize<'de> for TableDbTransactionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TableDbTransactionRequest
impl JsonSchema for TableDbTransactionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TableDbTransactionRequest
impl RefUnwindSafe for TableDbTransactionRequest
impl Send for TableDbTransactionRequest
impl Sync for TableDbTransactionRequest
impl Unpin for TableDbTransactionRequest
impl UnsafeUnpin for TableDbTransactionRequest
impl UnwindSafe for TableDbTransactionRequest