pub struct TableDbTransactionResponse {
pub tx_id: u32,
pub tx_op: TableDbTransactionResponseOp,
}Fields
tx_id: u32tx_op: TableDbTransactionResponseOpTrait Implementations
Sourceimpl Clone for TableDbTransactionResponse
impl Clone for TableDbTransactionResponse
Sourcefn clone(&self) -> TableDbTransactionResponse
fn clone(&self) -> TableDbTransactionResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableDbTransactionResponse
impl Debug for TableDbTransactionResponse
Sourceimpl<'de> Deserialize<'de> for TableDbTransactionResponse
impl<'de> Deserialize<'de> for TableDbTransactionResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TableDbTransactionResponse
impl JsonSchema for TableDbTransactionResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl !Freeze for TableDbTransactionResponse
impl RefUnwindSafe for TableDbTransactionResponse
impl Send for TableDbTransactionResponse
impl Sync for TableDbTransactionResponse
impl Unpin for TableDbTransactionResponse
impl UnsafeUnpin for TableDbTransactionResponse
impl UnwindSafe for TableDbTransactionResponse